==> order-center-domain-3.2.3-CLOUD-DEV-20241205.042912-31-sources.jar: com/tydic/dyc/oc/model/order/IUocOrderModel.java <==
package com.tydic.dyc.oc.model.order;

import com.tydic.dyc.base.bo.BasePageRspBo;
import com.tydic.dyc.oc.model.order.qrybo.*;
import com.tydic.dyc.oc.model.order.sub.*;

import java.util.List;

/**
 * 描述 订单领域方法服务
 *
 * @author tgy
 * @date 2022/2/13 17:30
 */
public interface IUocOrderModel {

    /**
     * 描述:保存订单信息
     * @param orderDo 入参
     * @return com.tydic.dyc.oc.model.order.UocOrderDo
     * @author tgy
     * @date 2022/2/22 15:10
     */
    UocOrderDo createOrder(UocOrderDo orderDo);

    /**
     * 描述:保存附件
     * @param uocOrderAccessoryList 入参
     * @return com.tydic.dyc.oc.model.order.UocOrderDo
     * @author tgy
     * @date 2022/2/22 15:10
     */
    UocOrderDo createOrderAccessory(List<UocOrderAccessory> uocOrderAccessoryList);

    /**
     * 描述:保存订单变更记录信息
     * @param uocOrderStateChgLog 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderStateChgLog
     * @author tkl
     * @date 2022/3/2 13:49
     */
    UocOrderStateChgLog createOrderStateChangeLog(UocOrderStateChgLog uocOrderStateChgLog);

    /**
     * 描述:保存获取件地址信息
     * @param uocOrdLogisticsRela 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrdLogisticsRela
     * @author tkl
     * @date 2022/5/20 15:49
     */
    UocOrdLogisticsRela createOrderLogisticsRela(UocOrdLogisticsRela uocOrdLogisticsRela);

    /**
     * 描述:查询
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.qrybo.UocOrderStakeholderQryBo
     * @author tgy
     * @date 2022/2/24 19:39
     */
    List<UocOrderStakeholderQryBo> qryStakeholderList(UocOrderStakeholderQryBo qryBo);

    /**
     * 描述:查询订单任务实例
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderTaskInst
     * @author tgy
     * @date 2022/2/24 19:39
     */
    List<UocOrderTaskInst> qryOrderTaskInstList(UocOrderTaskInstQryBo qryBo);

    /**
     * 描述:查询订单任务处理实例
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderTaskDeal
     * @author tgy
     * @date 2022/2/24 19:39
     */
    List<UocOrderTaskDeal> qryOrderTaskDealList(UocOrderTaskDealQryBo qryBo);

    /**
     * 描述:查询流程任务实例
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderProcInst
     * @author tgy
     * @date 2022/2/24 19:39
     */
    List<UocOrderProcInst> qryOrderProcInstList(UocOrderProcInstQryBo qryBo);

    /**
     * 描述:查询订单信息
     * @param uocOrderDo 入参
     * @return com.tydic.dyc.oc.model.order.UocOrderDo
     * @author tgy
     * @date 2022/2/27 15:57
     */
    UocOrderDo qryOrderBy(UocOrderDo uocOrderDo);

    /**
     * 描述:查询订单明细信息
     * @param uocOrderItemQryBo 入参
     * @return java.util.List<com.tydic.dyc.oc.model.order.sub.UocOrderItem></>
     * @author tgy
     * @date 2022/2/27 15:57
     */
    List<UocOrderItem> qryOrderItemList(UocOrderItemQryBo uocOrderItemQryBo);

    /**
     * 描述:查询收获地址信息
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrdLogisticsRela
     * @author tgy
     * @date 2022/2/27 15:57
     */
    UocOrdLogisticsRela qryOrderLogisticsRela(UocOrdLogisticsRelaQryBo qryBo);

    /**
     * 描述:查询发票信息
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrdInvoice
     * @author tgy
     * @date 2022/2/27 15:57
     */
    UocOrdInvoice qryOrderInvoice(UocOrdInvoiceQryBo qryBo);

    /**
     * 描述:查询订单附件
     *
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderAccessory
     * @author tkl
     * @date 2022/2/25 10:35
     */
    List<UocOrderAccessory> getOrderAccessoryList(UocOrderAccessoryQryBo qryBo);

    /**
     * 订单扩展查询
     *
     * @param qryBo
     * @return
     */
    List<UocOrderMap> qryOrderMapList(UocOrderMapQryBo qryBo);

    /**
     * 更新订单关联状态
     * @author wenle
     * @date 2022-04-01 15:16:26
     * @param uocOrderRel 入参
     */
    void dealRelUpdate(UocOrderRel uocOrderRel);

    /**
     * 查询关联状态
     *
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderRel
     * @author wenle
     * @date 2022-04-01 16:31:18
     */
    UocOrderRel qryRelInfo(UocOrderRelQryBo qryBo);

    /**
     * 查询关联状态
     *
     * @param qryBo
     * @return
     */
    List<UocOrderRel> qryListRelInfo(UocOrderRelQryBo qryBo);

    /**
     * 查询外部系统单号关联信息
     *
     * @param qryBo 入参
     * @return java.util.List<com.tydic.dyc.oc.model.order.sub.UocOrderQueryIndex></>
     * @author tkl
     * @date 2022-04-01 16:31:18
     */
    List<UocOrderQueryIndex> qryOrderQueryIndexList(UocOrderQueryIndexQryBo qryBo);

    /**
     * 创建关联状态
     * @author wenle
     * @date 2022-04-01 16:31:18
     * @param uocOrderRel 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderRel
     */
    void createRelInfo(UocOrderRel uocOrderRel);

    /**
     * 查询对账状态
     * @author wenle
     * @date 2022-04-01 19:50:33
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderCheckAccount
     */
    UocOrderCheckAccount qryCheckInfo(UocOrderCheckAccountQryBo qryBo);

    /**
     * 新增对账状态
     * @author wenle
     * @date 2022-04-01 19:50:33
     * @param uocOrderCheckAccount 入参
     */
    void createCheckInfo(UocOrderCheckAccount uocOrderCheckAccount);

    /**
     * 更新对账状态
     * @author wenle
     * @date 2022-04-01 19:50:33
     * @param uocOrderCheckAccount 入参
     */
    void updateCheckInfo(UocOrderCheckAccount uocOrderCheckAccount);

    /**
     * 描述：修改订单及订单明细销售价
     *
     * @author: daiyuanyuan
     * @date: 2022-04-02 15:45
     */
    void modifySalePrice(UocOrderDo uocOrderDo);

    /**
     * 查询评价配置
     */
    BasePageRspBo<UocConfEvaluate> qryListPageConfEvaluate(UocConfEvaluateQryBo uocConfEvaluateQryBo);

    /**
     * 查询时效配置
     */
    BasePageRspBo<UocConfEffective> qryListPageConfEffective(UocConfEffectiveQryBo uocConfEffectiveQryBo);
    /**
     * 新增评价配置
     */
    void addConfEvaluate(UocConfEvaluate uocConfEvaluate);

    /**
     * 修改评价配置
     */
    void modifyConfEvaluate(UocConfEvaluate uocConfEvaluate);

    /**
     * 删除评价配置
     */
    void deleteConfEvaluate(UocConfEvaluate uocConfEvaluate);

    /**
     * 根据ID查询评价配置
     *
     * @param id
     * @return
     */
    UocConfEvaluate getConfEvaluateById(Long id);

    /**
     * 调价计算评价配置数量
     *
     * @param uocConfEvaluate
     * @return
     */
    int getCheckConfEvaluate(UocConfEvaluate uocConfEvaluate);

    /**
     * 查询页签状态列表
     *
     * @param qryBo
     * @return java.util.List<com.tydic.dyc.oc.model.order.sub.UocConfTabOrdState></>
     */
    List<UocConfTabOrdState> qryConfTabOrdStateList(UocConfTabOrdStateQryBo qryBo);

    /**
     * 订单按钮配置类查询
     *
     * @param qryBo
     * @return java.util.List<com.tydic.dyc.oc.model.order.sub.UocConfButton></>
     */
    List<UocConfButton> qryConfButtonList(UocConfButtonQryBo qryBo);

    /**
     * 订单按钮配置类更新
     *
     * @param confButton
     * @return com.tydic.dyc.oc.model.order.sub.UocConfButton
     */
    UocConfButton updateConfButton(UocConfButton confButton);

    /***
     *  删除供应商下单限额配置
     * @param uocConfSupplier
     * @return
     */
    int deleteConfSupplierBy(UocConfSupplier uocConfSupplier);

    /***
     * 更新供应商下单限额配置
     * @param uocConfSupplier
     * @return
     */
    int updateConfSupplierById(UocConfSupplier uocConfSupplier);

    /***
     * 查询
     * @param supNo
     * @return
     */
    UocConfSupplier getConfSupplierModelById(long supNo);

    /***
     * 查询
     * @param uocConfSupplier
     * @return
     */
    UocConfSupplier getConfSupplierModelBy(UocConfSupplier uocConfSupplier);


    /***
     * 新增配置
     * @param uocConfSupplier
     * @return
     */
    int addConfSupplier(UocConfSupplier uocConfSupplier);
    /**
         * 描述：查询差异化超验配置在用列表
         *
         * @author: daiyuanyuan
         * @date:   2022-04-08 17:32
         */
    List<UocConfInspectionUse> qryInspectionConfigUseList(UocConfInspectionUse  uocConfInspectionUse);
    /**
     * 描述：查询差异化超验配置
     *
     * @author: daiyuanyuan
     * @date:   2022-04-08 17:32
     */
    List<UocConfInspection> qryInspectionConfigList(UocConfInspection  uocConfInspection);

    void updateInspectionConfigUse(UocConfInspectionUse  uocConfInspectionUse);

    /**
     *根据条件校验有多少条数据
     */
    int getCheckConfEffectiveBy(UocConfEffectiveQryBo uocConfEffectiveQryBo);

    /**
     * 创建时效类配置
     */
    void addConfEffective(UocConfEffective uocConfEffective);

    /**
     * 查询时效类配置
     */
    UocConfEffective getConfEffectiveBy(UocConfEffective uocConfEffective);

    /**
     * 删除时效
     */
    void deleteConfEffective(UocConfEffective uocConfEffective);

    /**
     * 更新时效
     */
    int updateEffectiveConfById(UocConfEffective effective);

    /*
     * @Author lsl
     * @Description //消息池表数量查看
     * @Date 17:20 2022/4/8
     * @Param []
     * @return
     */
    int getCheckMsg(UocDMsgPoolQryBo qryBo);

    /*
     * @Author lsl
     * @Description //TODO 消息池表生成消息
     * @Date 17:42 2022/4/8
     * @Param [qryBo]
     * @return int
     */
    int insertMsgPool(UocDMsgPoolQryBo qryBo);

    BasePageRspBo<ConfSupplierQryBo> getListPage(ConfSupplierQryBo confSupplierQryBo);
    void deleteInspectionConfig(UocConfInspection  uocConfInspection);

    void insertInspectionConfigByBatch(List<UocConfInspection>  uocConfInspections);

    /**
     * 同步评价数据表
     */
    void insertOrderEvaluate(UocEvaluate uocEvaluate);

    /**
     * 查询评价信息
     */
    List<UocEvaluate> qryOrderEvaluateList(UocEvaluateQryBo uocEvaluateQryBo);

    /**
     * 根据id，更新状态
     */
    void updateOrderEvaluate(UocEvaluate uocEvaluate);
    
    /*
     * @Author lsl
     * @Description //TODO 消息查询，用于消息处理
     * @Date 15:47 2022/4/11
     * @Param
     * @return
     */
   List<UocDMsgPoolQryBo> getListByRunResultAndFailureCount(UocDMsgPoolQryBo qryBo);
   
   /*
    * @Author lsl
    * @Description //TODO 查询妥投类消息
    * @Date 17:30 2022/4/12
    * @Param [qryBo]
    * @return java.util.List<com.tydic.dyc.oc.model.order.qrybo.UocDMsgPoolQryBo>
    */
    List<UocDMsgPoolQryBo> getVoteMsgList(UocDMsgPoolQryBo qryBo);

    List<UocDMsgPoolQryBo> getMsgList(UocDMsgPoolQryBo qryBo);

    UocDMsgPoolQryBo getModelByMsgId(UocDMsgPoolQryBo qryBo);
    
    void  updateMsgPoolById(UocDMsgPoolQryBo qryBo);
    
    void updateQueryIndexById(UocOrderQueryIndexQryBo qryBo);
    /**
     * 描述：修改订单及订单明细采购价
     *
     * @author: daiyuanyuan
     * @date: 2022-04-02 15:45
     */
    void modifyPurchasePrice(UocOrderDo uocOrderDo);

    List<UocTacheButton> qryTacheButton(UocTacheButtonQryBo uocTacheButtonQryBo);

    void modifyTabConf(UocConfTabOrdState uocConfTabOrdState);

    /**
     * 查询订单商品明细扩展
     *
     * @param uocOrderItemMapQryBo
     * @return
     */
    List<UocOrderItemMap> qryOrderItemMapList(UocOrderItemMapQryBo uocOrderItemMapQryBo);

    void deleteAuditConf(UocConfAudit uocConfAudit);

    List<UocConfAudit> qryListAuditConf(UocConfAuditQryBo uocConfAuditQryBo);

    void updateAuditConf(UocConfAudit uocConfAudit);

    void addExceptionAuditConf(UocConfAudit uocConfAudit);

    void updateOrderState(UocOrderDo uocOrderDo);


    /**
     * 描述:查询订单单列表
     * @param qryDo 入参
     * @return java.util.List<com.tydic.dyc.oc.model.order.UocOrderDo>
     * @author tgy
     * @date 2022/2/27 15:07
     */
    List<UocOrderDo> qryOrderList(UocOrderDo qryDo);

    UocConfAudit getAudit(UocConfAuditQryBo uocConfAuditQryBo);
    /**
     * 外部系统接口调用日志
     * @param uocOrderInterLog
     */
    void insertOrderInterLog(UocOrderInterLog uocOrderInterLog);
    
    int deleteOrderAccessory(UocOrderAccessory uocOrderAccessory);
}

==> order-center-domain-3.3.0-CLOUD-DEV-20251124.032633-3-sources.jar: com/tydic/dyc/oc/model/order/IUocOrderModel.java <==
package com.tydic.dyc.oc.model.order;

import com.tydic.dyc.base.bo.BasePageRspBo;
import com.tydic.dyc.oc.model.order.qrybo.*;
import com.tydic.dyc.oc.model.order.sub.*;

import java.util.List;

/**
 * 描述 订单领域方法服务
 *
 * @author tgy
 * @date 2022/2/13 17:30
 */
public interface IUocOrderModel {

    /**
     * 描述:保存订单信息
     * @param orderDo 入参
     * @return com.tydic.dyc.oc.model.order.UocOrderDo
     * @author tgy
     * @date 2022/2/22 15:10
     */
    UocOrderDo createOrder(UocOrderDo orderDo);

    /**
     * 描述:保存附件
     * @param uocOrderAccessoryList 入参
     * @return com.tydic.dyc.oc.model.order.UocOrderDo
     * @author tgy
     * @date 2022/2/22 15:10
     */
    UocOrderDo createOrderAccessory(List<UocOrderAccessory> uocOrderAccessoryList);

    /**
     * 描述:保存订单变更记录信息
     * @param uocOrderStateChgLog 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderStateChgLog
     * @author tkl
     * @date 2022/3/2 13:49
     */
    UocOrderStateChgLog createOrderStateChangeLog(UocOrderStateChgLog uocOrderStateChgLog);

    /**
     * 描述:保存获取件地址信息
     * @param uocOrdLogisticsRela 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrdLogisticsRela
     * @author tkl
     * @date 2022/5/20 15:49
     */
    UocOrdLogisticsRela createOrderLogisticsRela(UocOrdLogisticsRela uocOrdLogisticsRela);

    /**
     * 描述:查询
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.qrybo.UocOrderStakeholderQryBo
     * @author tgy
     * @date 2022/2/24 19:39
     */
    List<UocOrderStakeholderQryBo> qryStakeholderList(UocOrderStakeholderQryBo qryBo);

    /**
     * 描述:查询订单任务实例
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderTaskInst
     * @author tgy
     * @date 2022/2/24 19:39
     */
    List<UocOrderTaskInst> qryOrderTaskInstList(UocOrderTaskInstQryBo qryBo);

    /**
     * 描述:查询订单任务处理实例
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderTaskDeal
     * @author tgy
     * @date 2022/2/24 19:39
     */
    //List<UocOrderTaskDeal> qryOrderTaskDealList(UocOrderTaskDealQryBo qryBo);

    /**
     * 描述:查询流程任务实例
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderProcInst
     * @author tgy
     * @date 2022/2/24 19:39
     */
    List<UocOrderProcInst> qryOrderProcInstList(UocOrderProcInstQryBo qryBo);

    /**
     * 描述:查询订单信息
     * @param uocOrderDo 入参
     * @return com.tydic.dyc.oc.model.order.UocOrderDo
     * @author tgy
     * @date 2022/2/27 15:57
     */
    UocOrderDo qryOrderBy(UocOrderDo uocOrderDo);

    /**
     * 描述:查询订单明细信息
     * @param uocOrderItemQryBo 入参
     * @return java.util.List<com.tydic.dyc.oc.model.order.sub.UocOrderItem></>
     * @author tgy
     * @date 2022/2/27 15:57
     */
    List<UocOrderItem> qryOrderItemList(UocOrderItemQryBo uocOrderItemQryBo);

    /**
     * 描述:查询收获地址信息
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrdLogisticsRela
     * @author tgy
     * @date 2022/2/27 15:57
     */
    UocOrdLogisticsRela qryOrderLogisticsRela(UocOrdLogisticsRelaQryBo qryBo);

    /**
     * 描述:查询发票信息
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrdInvoice
     * @author tgy
     * @date 2022/2/27 15:57
     */
    UocOrdInvoice qryOrderInvoice(UocOrdInvoiceQryBo qryBo);

    /**
     * 描述:查询订单附件
     *
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderAccessory
     * @author tkl
     * @date 2022/2/25 10:35
     */
    List<UocOrderAccessory> getOrderAccessoryList(UocOrderAccessoryQryBo qryBo);

    /**
     * 订单扩展查询
     *
     * @param qryBo
     * @return
     */
    List<UocOrderMap> qryOrderMapList(UocOrderMapQryBo qryBo);

    /**
     * 更新订单关联状态
     * @author wenle
     * @date 2022-04-01 15:16:26
     * @param uocOrderRel 入参
     */
    void dealRelUpdate(UocOrderRel uocOrderRel);

    /**
     * 查询关联状态
     *
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderRel
     * @author wenle
     * @date 2022-04-01 16:31:18
     */
    UocOrderRel qryRelInfo(UocOrderRelQryBo qryBo);

    /**
     * 查询关联状态
     *
     * @param qryBo
     * @return
     */
    List<UocOrderRel> qryListRelInfo(UocOrderRelQryBo qryBo);

    /**
     * 查询外部系统单号关联信息
     *
     * @param qryBo 入参
     * @return java.util.List<com.tydic.dyc.oc.model.order.sub.UocOrderQueryIndex></>
     * @author tkl
     * @date 2022-04-01 16:31:18
     */
    List<UocOrderQueryIndex> qryOrderQueryIndexList(UocOrderQueryIndexQryBo qryBo);

    /**
     * 创建关联状态
     * @author wenle
     * @date 2022-04-01 16:31:18
     * @param uocOrderRel 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderRel
     */
    void createRelInfo(UocOrderRel uocOrderRel);

    /**
     * 查询对账状态
     * @author wenle
     * @date 2022-04-01 19:50:33
     * @param qryBo 入参
     * @return com.tydic.dyc.oc.model.order.sub.UocOrderCheckAccount
     */
    UocOrderCheckAccount qryCheckInfo(UocOrderCheckAccountQryBo qryBo);

    /**
     * 新增对账状态
     * @author wenle
     * @date 2022-04-01 19:50:33
     * @param uocOrderCheckAccount 入参
     */
    void createCheckInfo(UocOrderCheckAccount uocOrderCheckAccount);

    /**
     * 更新对账状态
     * @author wenle
     * @date 2022-04-01 19:50:33
     * @param uocOrderCheckAccount 入参
     */
    void updateCheckInfo(UocOrderCheckAccount uocOrderCheckAccount);

    /**
     * 描述：修改订单及订单明细销售价
     *
     * @author: daiyuanyuan
     * @date: 2022-04-02 15:45
     */
    void modifySalePrice(UocOrderDo uocOrderDo);

    /**
     * 查询评价配置
     */
    BasePageRspBo<UocConfEvaluate> qryListPageConfEvaluate(UocConfEvaluateQryBo uocConfEvaluateQryBo);

    /**
     * 查询时效配置
     */
    BasePageRspBo<UocConfEffective> qryListPageConfEffective(UocConfEffectiveQryBo uocConfEffectiveQryBo);
    /**
     * 新增评价配置
     */
    void addConfEvaluate(UocConfEvaluate uocConfEvaluate);

    /**
     * 修改评价配置
     */
    void modifyConfEvaluate(UocConfEvaluate uocConfEvaluate);

    /**
     * 删除评价配置
     */
    void deleteConfEvaluate(UocConfEvaluate uocConfEvaluate);

    /**
     * 根据ID查询评价配置
     *
     * @param id
     * @return
     */
    UocConfEvaluate getConfEvaluateById(Long id);

    /**
     * 调价计算评价配置数量
     *
     * @param uocConfEvaluate
     * @return
     */
    int getCheckConfEvaluate(UocConfEvaluate uocConfEvaluate);

    /**
     * 查询页签状态列表
     *
     * @param qryBo
     * @return java.util.List<com.tydic.dyc.oc.model.order.sub.UocConfTabOrdState></>
     */
    List<UocConfTabOrdState> qryConfTabOrdStateList(UocConfTabOrdStateQryBo qryBo);

    /**
     * 订单按钮配置类查询
     *
     * @param qryBo
     * @return java.util.List<com.tydic.dyc.oc.model.order.sub.UocConfButton></>
     */
    List<UocConfButton> qryConfButtonList(UocConfButtonQryBo qryBo);

    /**
     * 订单按钮配置类更新
     *
     * @param confButton
     * @return com.tydic.dyc.oc.model.order.sub.UocConfButton
     */
    UocConfButton updateConfButton(UocConfButton confButton);

    /***
     *  删除供应商下单限额配置
     * @param uocConfSupplier
     * @return
     */
    int deleteConfSupplierBy(UocConfSupplier uocConfSupplier);

    /***
     * 更新供应商下单限额配置
     * @param uocConfSupplier
     * @return
     */
    int updateConfSupplierById(UocConfSupplier uocConfSupplier);

    /***
     * 查询
     * @param supNo
     * @return
     */
    UocConfSupplier getConfSupplierModelById(long supNo);

    /***
     * 查询
     * @param uocConfSupplier
     * @return
     */
    UocConfSupplier getConfSupplierModelBy(UocConfSupplier uocConfSupplier);


    /***
     * 新增配置
     * @param uocConfSupplier
     * @return
     */
    int addConfSupplier(UocConfSupplier uocConfSupplier);
    /**
         * 描述：查询差异化超验配置在用列表
         *
         * @author: daiyuanyuan
         * @date:   2022-04-08 17:32
         */
    List<UocConfInspectionUse> qryInspectionConfigUseList(UocConfInspectionUse  uocConfInspectionUse);
    /**
     * 描述：查询差异化超验配置
     *
     * @author: daiyuanyuan
     * @date:   2022-04-08 17:32
     */
    List<UocConfInspection> qryInspectionConfigList(UocConfInspection  uocConfInspection);

    void updateInspectionConfigUse(UocConfInspectionUse  uocConfInspectionUse);

    /**
     *根据条件校验有多少条数据
     */
    int getCheckConfEffectiveBy(UocConfEffectiveQryBo uocConfEffectiveQryBo);

    /**
     * 创建时效类配置
     */
    void addConfEffective(UocConfEffective uocConfEffective);

    /**
     * 查询时效类配置
     */
    UocConfEffective getConfEffectiveBy(UocConfEffective uocConfEffective);

    /**
     * 删除时效
     */
    void deleteConfEffective(UocConfEffective uocConfEffective);

    /**
     * 更新时效
     */
    int updateEffectiveConfById(UocConfEffective effective);

    /*
     * @Author lsl
     * @Description //消息池表数量查看
     * @Date 17:20 2022/4/8
     * @Param []
     * @return
     */
    int getCheckMsg(UocDMsgPoolQryBo qryBo);

    /*
     * @Author lsl
     * @Description //TODO 消息池表生成消息
     * @Date 17:42 2022/4/8
     * @Param [qryBo]
     * @return int
     */
    int insertMsgPool(UocDMsgPoolQryBo qryBo);

    BasePageRspBo<ConfSupplierQryBo> getListPage(ConfSupplierQryBo confSupplierQryBo);
    void deleteInspectionConfig(UocConfInspection  uocConfInspection);

    void insertInspectionConfigByBatch(List<UocConfInspection>  uocConfInspections);

    /**
     * 同步评价数据表
     */
    void insertOrderEvaluate(UocEvaluate uocEvaluate);

    /**
     * 查询评价信息
     */
    List<UocEvaluate> qryOrderEvaluateList(UocEvaluateQryBo uocEvaluateQryBo);

    /**
     * 根据id，更新状态
     */
    void updateOrderEvaluate(UocEvaluate uocEvaluate);
    
    /*
     * @Author lsl
     * @Description //TODO 消息查询，用于消息处理
     * @Date 15:47 2022/4/11
     * @Param
     * @return
     */
   List<UocDMsgPoolQryBo> getListByRunResultAndFailureCount(UocDMsgPoolQryBo qryBo);
   
   /*
    * @Author lsl
    * @Description //TODO 查询妥投类消息
    * @Date 17:30 2022/4/12
    * @Param [qryBo]
    * @return java.util.List<com.tydic.dyc.oc.model.order.qrybo.UocDMsgPoolQryBo>
    */
    List<UocDMsgPoolQryBo> getVoteMsgList(UocDMsgPoolQryBo qryBo);

    List<UocDMsgPoolQryBo> getMsgList(UocDMsgPoolQryBo qryBo);

    UocDMsgPoolQryBo getModelByMsgId(UocDMsgPoolQryBo qryBo);
    
    void  updateMsgPoolById(UocDMsgPoolQryBo qryBo);
    
    void updateQueryIndexById(UocOrderQueryIndexQryBo qryBo);
    /**
     * 描述：修改订单及订单明细采购价
     *
     * @author: daiyuanyuan
     * @date: 2022-04-02 15:45
     */
    void modifyPurchasePrice(UocOrderDo uocOrderDo);

    List<UocTacheButton> qryTacheButton(UocTacheButtonQryBo uocTacheButtonQryBo);

    void modifyTabConf(UocConfTabOrdState uocConfTabOrdState);

    /**
     * 查询订单商品明细扩展
     *
     * @param uocOrderItemMapQryBo
     * @return
     */
    List<UocOrderItemMap> qryOrderItemMapList(UocOrderItemMapQryBo uocOrderItemMapQryBo);

    void deleteAuditConf(UocConfAudit uocConfAudit);

    List<UocConfAudit> qryListAuditConf(UocConfAuditQryBo uocConfAuditQryBo);

    void updateAuditConf(UocConfAudit uocConfAudit);

    void addExceptionAuditConf(UocConfAudit uocConfAudit);

    void updateOrderState(UocOrderDo uocOrderDo);


    /**
     * 描述:查询订单单列表
     * @param qryDo 入参
     * @return java.util.List<com.tydic.dyc.oc.model.order.UocOrderDo>
     * @author tgy
     * @date 2022/2/27 15:07
     */
    List<UocOrderDo> qryOrderList(UocOrderDo qryDo);

    UocConfAudit getAudit(UocConfAuditQryBo uocConfAuditQryBo);
    /**
     * 外部系统接口调用日志
     * @param uocOrderInterLog
     */
    void insertOrderInterLog(UocOrderInterLog uocOrderInterLog);
    
    int deleteOrderAccessory(UocOrderAccessory uocOrderAccessory);
}
